==> intel-media-driver-non-free_21.4.2+ds1.orig.tar.xz: media-driver-intel-media-21.4.2/media_softlet/agnostic/common/hw/vdbox/media_srcs.cmake <==
# Copyright (c) 2020-2021, Intel Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

set(TMP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_cmdpar.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_hcp_cmdpar.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_hcp_impl.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_hcp_itf.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_vdenc_cmdpar.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_vdenc_impl.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_vdenc_itf.h
)

set(HEADERS_
    ${HEADERS_}
    ${TMP_HEADERS_}
)

set(COMMON_HEADERS_
    ${COMMON_HEADERS_}
    ${TMP_HEADERS_}
)

source_group( "MHW\\Vdbox" FILES ${TMP_HEADERS_} )

media_add_curr_to_include_path()

==> intel-media-driver-non-free_22.3.1+ds1.orig.tar.xz: media-driver-intel-media-22.3.1/media_softlet/agnostic/common/hw/vdbox/media_srcs.cmake <==
# Copyright (c) 2020-2021, Intel Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

set(TMP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_cmdpar.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_hcp_cmdpar.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_hcp_impl.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_hcp_itf.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_huc_cmdpar.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_huc_impl.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_huc_itf.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_vdenc_cmdpar.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_vdenc_impl.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_vdenc_itf.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_avp_impl.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_avp_itf.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_avp_cmdpar.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_mfx_cmdpar.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_mfx_impl.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_mfx_itf.h
)

set(HEADERS_
    ${HEADERS_}
    ${TMP_HEADERS_}
)

set(COMMON_HEADERS_
    ${COMMON_HEADERS_}
    ${TMP_HEADERS_}
)

source_group( "MHW\\Vdbox" FILES ${TMP_HEADERS_} )

media_add_curr_to_include_path()
